@@ -215,21 +215,21 @@ class VideoDownloader:
                  registry=None, force_refresh=False,
                  flat_layout: bool = False,video_url =None):
 
-        self.video_url = self.url = get_corrected_url(url or video_url) 
+        self.video_url = get_corrected_url(url or video_url) 
         self.video_urls = make_list( self.video_url)
-
-        self.registry = registry or infoRegistry(video_root=download_directory,flat_layout=flat_layout)
+        self.download_directory = get_video_root(download_directory)
+        self.registry = registry or infoRegistry(video_root=self.download_directory,flat_layout=flat_layout)
         self.ydl_opts = ydl_opts or {}
         self.get_download = download_video
         self.user_agent = user_agent
         self.video_extention = video_extention
-        self.download_directory = get_video_root(download_directory)
+        
         self.output_filename = output_filename
         self.force_refresh = force_refresh
         self.flat_layout = flat_layout   # 🔑
         self.video_path=video_path
         self.info = self.registry.get_video_info(url=self.video_url, force_refresh=self.force_refresh)
-        self.video_path=self.info.get('video_path')
+        
         
         self.monitoring = True
         self.pause_event = threading.Event()
@@ -306,7 +306,7 @@ class VideoDownloader:
             self.video_path = info_video_path
             self.video_id = self.info.get("id")
             self.video_url = video_url
-            return info
+            return self.info
         ydl_opts = ydl_opts or self.ydl_opts or {}
         user_agent = user_agent or self.user_agent
         force_refresh = force_refresh or self.force_refresh
