@@ -1,6 +1,8 @@
 from .imports import *
 _LOCK = threading.RLock()
 VIDEO_ENV_KEY = "DATA_DIRECTORY"
+# near your helpers
+YT_ID_RE = re.compile(r"^[A-Za-z0-9_-]{11}$")
 # Full schema
 VIDEO_SCHEMA = {
     "video_path": "video.mp4",
@@ -31,12 +33,18 @@ def check_create_logs(string):
     if directory.lower() == directory:
         logger.info(f"this is the directory fudd\n\n\n{string}")
     
+
 def generate_video_id(path_or_title: str, max_length: int = 50) -> str:
     base = os.path.splitext(os.path.basename(path_or_title))[0]
     if base == 'video':
         base = os.path.basename(os.path.dirname(path_or_title)) or base
-    base = get_normalize_ascii(base.lower())
-    base = re.sub(r'[^a-z0-9]+', '-', base).strip('-')
+    # 👇 preserve case for YouTube-like IDs
+    if YT_ID_RE.match(base):
+        return base
+
+    # keep the rest as "slug"
+    base = get_normalize_ascii(base)          # NOTE: no .lower() here
+    base = re.sub(r'[^a-zA-Z0-9]+', '-', base).strip('-')
     base = re.sub(r'-{2,}', '-', base)
     if len(base) > max_length:
         h = get_sha12(base)
